==> apdu_service_plugin-0.0.13.tar.gz: lib/apdu_service_plugin.dart <==
import 'dart:async';
import 'dart:ffi';

import 'package:flutter/services.dart';

class ApduServicePlugin {
  static const MethodChannel _channel = MethodChannel('apdu_service_plugin');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<bool> startApdu(String nfcCode, String broadastPackageName,
      String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('startApdu', {
      'NFC_CODE': nfcCode,
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> stopApdu(
      String broadastPackageName, String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('stopApdu', {
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> setSharedPreferences(String sharedPrefName,
      String sharedPrefKey, String sharedPrefValue) async {
    final bool result = await _channel.invokeMethod('setSharedPreferences', {
      'SHARED_PREF_NAME': sharedPrefName,
      'SHARED_PREF_KEY': sharedPrefKey,
      'SHARED_PREF_VALUE': sharedPrefValue,
    });
    return result;
  }

  static Future<bool> removeSharedPreferences(String sharedPrefName,
      String sharedPrefKey, String sharedPrefValue) async {
    final bool result = await _channel.invokeMethod('removeSharedPreferences', {
      'SHARED_PREF_NAME': sharedPrefName,
      'SHARED_PREF_KEY': sharedPrefKey,
    });
    return result;
  }
}

==> apdu_service_plugin-0.0.14.tar.gz: lib/apdu_service_plugin.dart <==
import 'dart:async';
import 'dart:ffi';

import 'package:flutter/services.dart';

class ApduServicePlugin {
  static const MethodChannel _channel = MethodChannel('apdu_service_plugin');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<bool> startApdu(String nfcCode, String broadastPackageName,
      String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('startApdu', {
      'NFC_CODE': nfcCode,
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> stopApdu(
      String broadastPackageName, String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('stopApdu', {
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> setSharedPreferences(String sharedPrefName,
      String sharedPrefKey, String sharedPrefValue) async {
    final bool result = await _channel.invokeMethod('setSharedPreferences', {
      'SHARED_PREF_NAME': sharedPrefName,
      'SHARED_PREF_KEY': sharedPrefKey,
      'SHARED_PREF_VALUE': sharedPrefValue,
    });
    return result;
  }

  static Future<bool> removeSharedPreferences(
      String sharedPrefName, String sharedPrefKey) async {
    final bool result = await _channel.invokeMethod('removeSharedPreferences', {
      'SHARED_PREF_NAME': sharedPrefName,
      'SHARED_PREF_KEY': sharedPrefKey,
    });
    return result;
  }
}
